Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Budget Service.

Actions, resources, and condition keys for AWS Budget Service - Service Authorization Reference

# Actions, resources, and condition keys for AWS Budget Service

AWS Budget Service (service prefix: `budgets` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Budget Service
- Resource types defined by AWS Budget Service
- Condition keys for AWS Budget Service

## Actions defined by AWS Budget Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

###### Note

The actions in this table are not APIs, but are instead permissions that grant access to the AWS Billing and Cost Management APIs that access budgets.

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateBudgetAction | Grants permission to configure a response that executes once your budget exceeds a specific budget threshold. Creating a budget action with tags also requires the 'budgets:TagResource' permission | Write | budgetAction* |  | iam:PassRole
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
DeleteBudgetAction | Grants permission to delete an action that is associated with a specific budget | Write | budgetAction* |  |
DescribeBudgetAction | Grants permission to retrieve the details of a specific budget action associated with a budget | Read | budgetAction* |  |
DescribeBudgetActionHistories | Grants permission to retrieve a historical view of the budget actions statuses associated with a particular budget action. These status include statues such as 'Standby', 'Pending' and 'Executed' | Read | budgetAction* |  |
DescribeBudgetActionsForAccount | Grants permission to retrieve the details of all of the budget actions associated with your account | Read |  |  |
DescribeBudgetActionsForBudget | Grants permission to retrieve the details of all of the budget actions associated with a budget | Read | budget* |  |
ExecuteBudgetAction | Grants permission to initiate a pending budget action as well as reverse a previously executed budget action | Write | budgetAction* |  |
ListTagsForResource | Grants permission to view resource tags for a budget or budget action | Read | budget |  |
budgetAction |  |
ModifyBudget | Grants permission to create and modify budgets, and edit budget details. Creating a budget with tags also requires the 'budgets:TagResource' permission | Write | budget* |  |
TagResource | Grants permission to apply resource tags to a budget or budget action. Also needed to create a budget or budget action with tags | Tagging | budget |  |
budgetAction |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove resource tags from a budget or budget action | Tagging | budget |  |
budgetAction |  |
| aws:TagKeys |
UpdateBudgetAction | Grants permission to update the details of a specific budget action associated with a budget | Write | budgetAction* |  | iam:PassRole
ViewBudget | Grants permission to view budgets and budget details | Read | budget* |  |

## Resource types defined by AWS Budget Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
budget | `arn:$ { Partition}:budgets::$ { Account}:budget/$ { BudgetName}` | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys
budgetAction | `arn:$ { Partition}:budgets::$ { Account}:budget/$ { BudgetName}/action/$ { ActionId}` | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys

## Condition keys for AWS Budget Service

AWS Budget Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access based on the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access based on the tags associated with the resource | String
aws:TagKeys | Filters access based on the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.